@@ -5,10 +5,18 @@
 #
 # Copyright 2022 Carlos Carvalho
 #
+from . import config  # noqa
 from . import version
 from .database import update_database, search_company, database_info
 from .company import Company
 
+
 __version__ = version.version
 __author__ = "Carlos Carvalho"
-__all__ = ['Company', 'update_database', 'search_company', 'database_info']
+
+__all__ = [
+    "Company",
+    "update_database",
+    "search_company",
+    "database_info",
+]
