@@ -4,13 +4,10 @@ Abreviations used in code:
     dfi = input dataframe
     dfo = output dataframe
 """
-import os
 from typing import Literal
 import numpy as np
 import pandas as pd
-
-BASE_DIR = os.path.dirname(__file__)
-MAIN_DF_PATH = BASE_DIR + "/data/main_df.pkl.zst"
+from . import config as c
 
 
 class Company:
@@ -80,7 +77,7 @@ class Company:
         """
         # Create custom data frame for ID selection
         df = (
-            pd.read_pickle(MAIN_DF_PATH)[["cvm_id", "fiscal_id"]]
+            c.main_df[["cvm_id", "fiscal_id"]]
             .drop_duplicates()
             .astype({"cvm_id": int, "fiscal_id": str})
         )
@@ -191,8 +188,7 @@ class Company:
 
     def _set_main_data(self) -> pd.DataFrame:
         self._COMP_DF = (
-            pd.read_pickle(MAIN_DF_PATH)
-            .query("cvm_id == @self._cvm_id")
+            c.main_df.query("cvm_id == @self._cvm_id")
             .astype(
                 {
                     "co_name": str,
@@ -226,7 +222,7 @@ class Company:
         ].max()
 
     def info(self) -> pd.DataFrame:
-        """Return dictionary with company info."""
+        """Return dataframe with company info."""
         company_info = {
             "Name": self._NAME,
             "CVM ID": self._cvm_id,
@@ -239,9 +235,8 @@ class Company:
             "Last Annual Report": self._LAST_ANNUAL.strftime("%Y-%m-%d"),
             "Last Quarterly Report": self._LAST_QUARTERLY.strftime("%Y-%m-%d"),
         }
-        df = pd.DataFrame.from_dict(
-            company_info, orient="index", columns=["Company Info"]
-        )
+        df = pd.DataFrame.from_dict(company_info, orient="index", columns=["Values"])
+        df.index.name = "Company Info"
         return df
 
     def report(
@@ -496,6 +491,8 @@ class Company:
         dfo.loc["ebitda_margin"] = ebitda / revenues
         dfo.loc["operating_margin"] = ebit * (1 - self._tax_rate) / revenues
         dfo.loc["net_margin"] = net_income / revenues
+
+        dfo.index.name = "Company Financial Indicators"
         # Show only the selected number of years
         if num_years > 0:
             dfo = dfo[dfo.columns[-num_years:]]
